diff libpurple/protocols/gg/confer.h @ 15822:32c366eeeb99

sed -ie 's/gaim/purple/g'
author Sean Egan <seanegan@gmail.com>
date Mon, 19 Mar 2007 07:01:17 +0000
parents 5fe8042783c1
children 44b4e8bd759b
line wrap: on
line diff
--- a/libpurple/protocols/gg/confer.h	Mon Mar 19 06:11:46 2007 +0000
+++ b/libpurple/protocols/gg/confer.h	Mon Mar 19 07:01:17 2007 +0000
@@ -1,7 +1,7 @@
 /**
  * @file confer.h
  *
- * gaim
+ * purple
  *
  * Copyright (C) 2005  Bartosz Oler <bartosz@bzimage.us>
  *
@@ -21,42 +21,42 @@
  */
 
 
-#ifndef _GAIM_GG_CONFER_H
-#define _GAIM_GG_CONFER_H
+#ifndef _PURPLE_GG_CONFER_H
+#define _PURPLE_GG_CONFER_H
 
 #include "gg.h"
 
 /**
  * Finds a CHAT conversation for the current account with the specified name.
  *
  * @param gc   GaimConnection instance.
  * @param name Name of the conversation.
  *
  * @return GaimConversation or NULL if not found.
  */
-GaimConversation *
-ggp_confer_find_by_name(GaimConnection *gc, const gchar *name);
+PurpleConversation *
+ggp_confer_find_by_name(PurpleConnection *gc, const gchar *name);
 
 /**
  * Adds the specified UIN to the specified conversation.
  * 
- * @param gc        GaimConnection.
+ * @param gc        PurpleConnection.
  * @param chat_name Name of the conversation.
  */
 void
-ggp_confer_participants_add_uin(GaimConnection *gc, const gchar *chat_name,
+ggp_confer_participants_add_uin(PurpleConnection *gc, const gchar *chat_name,
 						    const uin_t uin);
 
 /**
  * Add the specified UINs to the specified conversation.
  *
- * @param gc         GaimConnection.
+ * @param gc         PurpleConnection.
  * @param chat_name  Name of the conversation.
  * @param recipients List of the UINs.
  * @param count      Number of the UINs.
  */
 void
-ggp_confer_participants_add(GaimConnection *gc, const gchar *chat_name,
+ggp_confer_participants_add(PurpleConnection *gc, const gchar *chat_name,
 			    const uin_t *recipients, int count);
 
 /**
@@ -65,29 +65,29 @@
  * TODO: This function should be rewritten to better handle situations when
  * somebody adds more people to the converation.
  *
- * @param gc         GaimConnection.
+ * @param gc         PurpleConnection.
  * @param recipients List of the people in the conversation.
  * @param count      Number of people.
  *
  * @return Name of the conversation.
  */
 const char*
-ggp_confer_find_by_participants(GaimConnection *gc, const uin_t *recipients,
+ggp_confer_find_by_participants(PurpleConnection *gc, const uin_t *recipients,
 						    int count);
 
 /**
  * Adds a new conversation to the internal list of conversations.
  * If name is NULL then it will be automagically generated.
  *
- * @param gc   GaimConnection.
+ * @param gc   PurpleConnection.
  * @param name Name of the conversation.
  * 
  * @return Name of the conversation.
  */
 const char*
-ggp_confer_add_new(GaimConnection *gc, const char *name);
+ggp_confer_add_new(PurpleConnection *gc, const char *name);
 
 
-#endif /* _GAIM_GG_CONFER_H */
+#endif /* _PURPLE_GG_CONFER_H */
 
 /* vim: set ts=8 sts=0 sw=8 noet: */
@@ -21,42 +21,42 @@
  * Finds a CHAT conversation for the current account with the specified name.
  *
- * @param gc   GaimConnection instance.
+ * @param gc   PurpleConnection instance.
  * @param name Name of the conversation.
  *
@@ -21,42 +21,42 @@
  * @param name Name of the conversation.
  *
- * @return GaimConversation or NULL if not found.
+ * @return PurpleConversation or NULL if not found.
  */